# Vol d'une base de données confidentielle

Un des pires scénarios qui peut subvenir dans une organisation est le vol d'une base de données confidentielles. En plus de devoir gérer le risque de fraude d'identité des clients ainsi que la perte de propriété intellectuelle, l'entreprise doit aussi rapidement se remettre sur pied, rétablir sa réputation et adopter de meilleures pratiques. Il y aura aussi une remise en question de la pertinence et de l'utilisation des données accumulées historiquement.

Les principales causes d'un vol de données sont:

- L'infection par un maliciel de type rançongiciel.
- L'intrusion depuis Internet par des acteurs malicieux
- L'employé malicieux qui obtient des privilèges
- Le vol d'équipement informatique

## Comment éviter cette histoire d'horreur?

### Bien définir le rôle de ses employés

Le premier élément d'une bonne stratégie pour réduire le risque de vol d'une base de données confidentielles, c'est de bien définir les rôles des employés. Un rôle est généralement un ensemble de tâches nécessitant l'accès à un sous-ensemble de données. Ce modèle de gestion se nomme le Role Based Access Control, plus souvent rencontré sous l'acronyme RBAC.

Il faut ici différencier l'utilisateur du rôle. L'utilisateur est l'entité qui permet l'identification et l'authentification auprès d'une système informatique. Plus communément, on parle de la paire identifiant et mot de passe.

Le rôle ne possène pas de capacité d'identification et d'authentification. Cependant, il possède des permissions d'accès et d'exécution. Chaque utilisateur peut posséder un ou plusieurs rôles. Dans les meilleures pratiques, les utilisateurs n'ont qu'un seul rôle à la fois, ce qui permet d'éviter les croisements de données.

Une liste minimale de rôles dans une organisation pourrait être:

- Conseil d'administration
- Gestion
- Service informatique
- Comptabilité
- Ressources humaines
- Expérience client
- Approvisionnement
- Ventes

### Contrôler l'accès aux données

Voici le second élément de notre stratégie. Nous allons définir, pour chacun des rôles, à quoi ils devraient avoir accès. 

Dans une entreprise de distribution, les employés sur la route ne devraient accéder qu'aux données des clients sur leur territoire. On effectue donc un filtre de la table des clients basé sur la géolocalisation. C'est une forme de gestion des accès basé sur les enregistrements.

Dans un autre scénario, nous nous intéressons aux employés du service téléphonique. Ils ne devraient avoir accès qu'aux renseignements qu'ils ont droit de divulguer aux clients par la voix. Les informations qui sont communiquées par des systèmes automatisés doivent être cachées. Par exemple, ils ne devraient pas avoir accès aux champs contenant les numéros de carte de crédit, ni aux mots de passe. C'est ici une forme de gestion des accès basé sur les attributs

Enfin, lorsque nous devons restreindre à la fois sur des enregistrement et des colonnes, il peut être utile de créer des vues, c'est-à-dire des requêtes pré-formatées aux besoins du rôle, présentées sous la forme de tables.

### Utiliser le masquage et anonymisation

La réalité du monde de l'entreprise, c'est qu'il n'y a pas de solution universelle. 

Parfois, certains employés ont besoin de voir les vraies données. Par exemple, les gestionnaires des ressources humaines ont parfois besoin d'accéder aux information médicales ou aux numéros d'assurance sociale des employés.

Dans d'autres scénarios, de nombreux rapports et systèmes dérivés consomment des bases de données existantes, qui ne pourraient pas facilement être recréées avec les principes de gestion des accès que nous avons décrit ci-haut. On ne veut pas tout recommencer !

Un autre aspect à considérer, est que, parfois, seule une partie du champ est sensible. Les six premiers chiffres d'une carte de crédit décrivent l'émetteur de la carte, alors que les trois premiers caractères du code postal canadien identifie une ville ou un quartier.

Dans ces situations, on aura alors recours à un procédé de masquage des données. Celui-ci permet de cacher, partiellement ou complètement, les informations contenues dans un champ. Voici quelques exemples de masquage de champs dans une base de données.

- Une adresse courriel apparaît sous la forme suivante: `xxx@domaine.com`
- Une date de naissance est arrondie au mois près: `2000-04-00`
- Les noms de famille des employés sont substitués par des personnages de dessins animés: `François Superman`
- Un numéro de carte de crédit présente seulement les 4 derniers chiffres: `XXXX XXXX XXXX 1234`

## Trop tard... Quoi faire, maintenant?

Tout comme avec l'attaque par rançongiciel, si l'attaque a pu être détectée immédiatement, la première chose à faire est de limiter les accès réseau, couper l'accès à Internet et aviser les autorités publiques.

Si l'incident a eu lieu il y a plus d'une journée, c'est vraiment trop tard pour contrer la diffusion des renseignements sur le web profond. C'est plutôt le temps de repenser sa stratégie de gestion des données et de mettre en oeuvre les conseils de ce guide immédiatement. Laissez les spécialistes en cybersécurité et la police faire le reste et collaborez avec eux. 

Le moment venu, informez le public de l'incident que vous avez vécu et des étapes que vous avez mis en place pour améliorer votre sécurité.

## Conclusion

Afin de trouver le bon équilibre dans l'utilisation de toutes les méthodes de prévention, il est important de considérer que c'est toujours un compromis entre la protection de la confidentialité, de la vie privée et la valeur de la donnée qui est accessible à l'utilisateur.

La sécurité est un exercice de gestion de risques, et lorsque les incidents se produisent, il vaut toujours mieux regarder en avant et mieux se préparer pour la prochaine fois.

