# La corruption d'un système Linux

Un serveur Linux est un environnement où il est très important d'avoir une stabilité. Ceci s'observe notamment avec l'utilisation de distributions qui ont un cycle de développement et de test beaucoup plus long que celles qui sont utilisées pour la bureautique. 

Cette stabilité est souvent la conséquence de choix de versions de logiciels qui plus anciennes, mais éprouvées. Il peut alors être tentant de mettre à jour certaines composantes d'un système afin de profiter des dernières nouveautés. 

Cependant, dans un environnement de production, ce comportement met à risque le bon fonctionnement de l'ensemble des applications. De plus, la modification de fichiers système peut mener à des erreurs et même à la corruption du serveur.

## Comment éviter cette histoire d'horreur?

Voici quelques astuces pour prévenir la corruption d'un serveur ou pour en faciliter la reprise.

### Apprendre les bases du fonctionnement d'un système Linux

Les systèmes Linux sont le fruit de plusieurs décennies, avant même la création de Linux par Linux Torvalds. La philosophie Unix, le mouvement du logiciel libre et les impératifs de stabilité en production ont dicté plusieurs normes. Celles-ci sont aujourd'hui centrales au bon fonctionnement des systèmes d'exploitation et de l'Internet.

C'est un sujet beaucoup trop vaste pour en discuter en détail dans un livrel, mais, au moins, voici quelques sujets importants à explorer!

- Le rôle du noyau Linux
- Le système de paquetages
- Les fichiers de configuration
- Les services système
- Les services réseau

Voici le guide d'administration de Debian, disponible dans plusieurs langues et plusieurs formats, qui permet de couvrir l'ensemble de ces sujets, et bien plus!

- [Debian Buster from Discovery to Mastery](https://debian-handbook.info/get/now/)

### Bien utiliser le rôle de superutilisateur

Le rôle de superutilisateur sur Linux possède beaucoup plus de privilèges que sur un système Windows. Il peut vraiment tout faire! Il faut comprendre par là qu'il peut supprimer ou écraser n'importe quel fichier, sans avertissement.

Lorsqu'on souhaite expérimenter avec une nouveauté, il est généralement déconseillé de le faire en tant que superutilisateur. Il vaut mieux créer un rôle utilisateur spécifique pour effectuer les tests.

### Installation d'une compilation manuelle dans un répertoire alternatif

Dans le cas de la compilation de librairies, on peut alors utiliser un répertoire d'installation différent que celui par défaut, qui est souvent localisé dans les répertoires systèmes. Pour la configuration qui précède la compilation avec `make`, on peut définir un préfixe:

```bash
./configure --prefix=/mon/répertoire/non/système/
```

### Librairies associées à un langage de programmation

Dans le cas de librairies associées à un langage de programmation en particulier, tel que Python, il est conseillé d'installer les versions qui ne sont pas déjà empaquetées par la distribution avec un rôle utilisateur régulier.

Pour simplifier, il faut éviter l'utilisation de `sudo pip install quelquechose` et privilégier `pip install quelquechose` le plus possible. Ceci peut aussi se faire au sein d'un environnement virtuel `virtualenv`.

### Utiliser les environnements virtuels tels que Docker

La virtualisation permet de partager des ressources entre un système hôte et un système client, tout en conservant un niveau d'isolation élevé au niveau de la sécurité et du système de fichiers.

Le logiciel [Docker](https://docs.docker.com/get-docker/) permet de créer des environnements d'exécution qui sont isolés d'une bonne partie du système principal, à l'exception du noyau, du processeur et de la mémoire. Il est possible de partager certaines ressources additionnelles, dont certains répertoires et le réseau informatique.

Docker est idéal pour expérimenter et pour mettre en place une agilité dans le développement. Donc, c'est un outil tout indiqué pour tester de nouvelles idées sans mettre en péril la stabilité de son système.

Le logiciel Docker fonctionne maintenant sur Windows et macOS, mais il était à l'origine développée uniquement pour le noyau Linux.

### Utiliser des captures incrémentales des fichiers système

Timeshift est une application Linux qui permet de faire des points de restauration système de la même manière que la fonctionnalité de Windows qui a été présentée à la fin du chapitre précédent. À la différence d'une restauration complète des fichiers, cette application se concentre sur les fichiers système.

L'application est simple à utiliser en mode graphique. Lors de son ouverture, elle demandera de sélectionner un mode de sauvegarde et un disque où effectuer la sauvegarde. Ensuite, la fréquence désirée des sauvegardes sera demandée. Enfin, il sera possible de créer le premier instantané, qui est le plus long à exécuter.

![](chapitre-02-restauration-timeshift.png)

Sur un serveur, nous ne disposons habituellement pas d'une interface graphique. L'application sera donc appelée par le terminal. Il faut alors spécifier le disque de sauvegarde par son identifiant système.

```bash
sudo timeshift --create --comments "instantané initial" --tags D --snapshot-device/dev/sda1
```

## Trop tard... Quoi faire, maintenant?

Une fois que le mal est fait, on peut se demander quelles sont nos options pour réparer un serveur corrompu ? Malheureusement, si nous ne nous sommes pas préparés à cette possibilité, ça peut être difficile. Voici deux options possibles, selon la situation dans laquelle on se trouve. Dans le premier cas, il est recommandé de ne pas redémarrer le système avant la réinstallation du paquetage. Dans le deuxième cas, s'il est requis de redémarrer, il faut comprendre qu'il est possible qu'il ne soit plus possible de démarrer le système si la restauration échoue.

### Purger et réinstaller un paquetage système

Si le fichier qui a été corrompu peut être identifié et est relié à un paquetage de la distribution, en purgeant le paquetage et en le réinstallant, on a de bonnes chances de résoudre le problème. Cependant, s'il y a des dépendances, ça peut s'avérer un travail de recherche complexe. De plus, si le fichier corrompu est utilisé par le gestionnaire de paquetages. alors il ne sera pas possible de poursuivre.

### Restaurer une capture incrémentale antérieure

L'avantage de la méthode de la capture incrémentale, c'est qu'elle facilite grandement la restauration. Pour appliquer une capture incrémentale antérieure avec Timeshift, il suffit d'exécuter cette commande:

```bash
sudo timeshift --restore
```

Le logiciel demandera quel instantané restaurer, puis proposera de mettre à jour le gestionnaire de démarrage GRUB, au besoin. Si la restauration est effectuée avec succès, le tour est joué. Sinon, il reste alors une seule solution, si vous avez accès physiquement au serveur.

### La restauration depuis un système de secours

Les disques d'installation des distributions Linux incluent souvent une version "live session" qui permet de démarrer sur le système désiré sans avoir à modifier son système avant de faire l'installation. Ceux-ci permettent aussi aux utilisatrices et utilisateurs expérimentés de modifier un système d'exploitation existant, en utilisant la technique du changement de racine avec l'outil `chroot`.

Voici un exemple de procédure pour effectuer une connexion `chroot` avec le système Manjaro, en utilisant le terminal, depuis un disque chiffré. Comme avec toute liste de commandes Linux, prenez le temps d'exécuter chacune des étapes une par une et évitez les copier-coller.

```bash
# Se connecter en root
sudo su -
# Créer un répertoire de secours a la racine, par exemple: /rescue
mkdir /rescue
# Mettre le nom du disque qui contient le système crypté, ex: /dev/nvme0n1p2
udisksctl unlock -b /dev/nvme0n1p2
# La fonction va retourner le nouvel emplacement du disque décrypté, par exemple: /dev/dm-0.
# Monter le disque décrypté dans le répertoire de secours
sudo mount /dev/dm-0 /rescue
# Joindre le répertoire
mount -o bind/rescue/rescue
# Installer l outil arch-chroot
pacman -Sy arch-install-scripts
# Aller en chroot
arch-chroot /rescue
# Nous sommes maintenant sur le système installe en chroot, exécuter les commandes de dépannage sur place
```